package info.aspirecn.iov.sjjh.supplier10000053.util;

import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.supplier10000053.exception.ServiceException;
import lombok.extern.slf4j.Slf4j;
import okhttp3.*;

import java.io.IOException;
import java.net.SocketTimeoutException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.concurrent.TimeUnit;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Slf4j
public class HttpUtil {
    private static OkHttpClient okHttpClient = new OkHttpClient.Builder().build();

    public static String doGet(int outTime, String url) throws IOException {
        Request request = new Request.Builder()
                .url(url)
                .build();
        OkHttpClient client = okHttpClient.newBuilder()
                .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                .readTimeout(outTime, TimeUnit.MILLISECONDS)
                .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                .build();

        String responseContext = "";
        Response response = client.newCall(request).execute();
        if (response.body() != null) {
            responseContext = response.body().string();
        }
        return responseContext;
    }

    private static final String MEDIA_TYPE = "application/json;charset=UTF-8";

    public static String doPost(String url, String body, long timeOut, String authorization) {
        OkHttpClient okHttpClient = new OkHttpClient.Builder().build();
        MediaType mediaType = MediaType.parse(MEDIA_TYPE);
        RequestBody requestBody = RequestBody.create(mediaType, body);

        Request okRequest = new Request.Builder()
                .post(requestBody)
                .header("token", authorization)
                .url(url)
                .build();
        OkHttpClient client = okHttpClient.newBuilder()
                .connectTimeout(timeOut, TimeUnit.MILLISECONDS)
                .readTimeout(timeOut, TimeUnit.MILLISECONDS)
                .writeTimeout(timeOut, TimeUnit.MILLISECONDS)
                .build();

        String responseContext = "";
        try {
            Response response = client.newCall(okRequest).execute();

            if (response.body() != null) {
                responseContext = response.body().string();
            }

        } catch (SocketTimeoutException ste) {
            log.info("supplier10000053.doPost-SocketTimeoutException：{}", ste);
            throw new ServiceException(Constant.REQUEST_TIMEOUT, String.format("调用上游超时，失败原因: %s", ste.getMessage()), ste);
        } catch (IOException ioe) {
            log.info("supplier10000053.doPost-IOException：{}", ioe);
            throw new ServiceException(Constant.FAIL, String.format("调用上游失败，失败原因: %s", ioe.getMessage()), ioe);
        } catch (Exception e) {
            log.info("supplier10000053.doPost-Exception：{}", e);
            throw new ServiceException(Constant.FAIL, String.format("调用上游失败，失败原因: %s", e.getMessage()), e);

        }
        return responseContext;
    }

    public static void main(String[] args) {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyMMddhhmmss");
        System.out.println(simpleDateFormat.format(new Date()) + (String.valueOf(System.currentTimeMillis()).substring(0, 8)));
        System.out.println();
    }
}
